@@ -10,10 +10,9 @@ transformation or as part of a Pipeline.
 import json
 
 from monty.json import MontyDecoder
-
-from pymatgen.ext.matproj import MPRester
-from pymatgen.core.structure import IStructure
 from pymatgen.core.composition import Composition
+from pymatgen.core.structure import IStructure
+from pymatgen.ext.matproj import MPRester
 from pymatgen.io.ase import AseAtomsAdaptor
 
 from matminer.featurizers.base import BaseFeaturizer
@@ -71,7 +70,7 @@ class ConversionFeaturizer(BaseFeaturizer):
                 featurize. Can be multiple labels if the featurize function
                 requires multiple inputs.
             **kwargs: Additional keyword arguments that will be passed through
-                to `BseFeaturizer.featurize_dataframe()`.
+                to `BaseFeaturizer.featurize_dataframe()`.
 
         Returns:
             (Pandas.Dataframe): The updated dataframe.
@@ -81,9 +80,9 @@ class ConversionFeaturizer(BaseFeaturizer):
         target = self._target_col_id
         if isinstance(target, str) and target[0] == "_":
             if "multiindex" in kwargs and kwargs["multiindex"]:
-                self._target_col_id = "{}_{}".format(col_id[-1], target[1:])
+                self._target_col_id = f"{col_id[-1]}_{target[1:]}"
             else:
-                self._target_col_id = "{}_{}".format(col_id, target[1:])
+                self._target_col_id = f"{col_id}_{target[1:]}"
         elif target is None:
             self._target_col_id = col_id
 
@@ -406,6 +405,11 @@ class StructureToOxidStructure(ConversionFeaturizer):
     def __init__(self, target_col_id="structure_oxid", overwrite_data=False, return_original_on_error=False, **kwargs):
         super().__init__(target_col_id, overwrite_data)
         self.oxi_guess_params = kwargs
+
+        # Set sensible default for max_sites if not in kwargs
+        if "max_sites" not in kwargs:
+            kwargs["max_sites"] = -50
+
         self.return_original_on_error = return_original_on_error
 
     def featurize(self, structure):
@@ -485,6 +489,11 @@ class CompositionToOxidComposition(ConversionFeaturizer):
         **kwargs,
     ):
         super().__init__(target_col_id, overwrite_data)
+
+        # Set sensible default for max_sites if not in kwargs
+        if "max_sites" not in kwargs:
+            kwargs["max_sites"] = -50
+
         self.oxi_guess_params = kwargs
         self.coerce_mixed = coerce_mixed
         self.return_original_on_error = return_original_on_error
@@ -648,7 +657,7 @@ class PymatgenFunctionApplicator(ConversionFeaturizer):
         self.set_n_jobs(1)
 
     def featurize(self, obj):
-        return self.func(obj, *self.func_args, **self.func_kwargs)
+        return (self.func(obj, *self.func_args, **self.func_kwargs),)
 
     def implementors(self):
         return ["Alex Dunn"]
@@ -670,7 +679,7 @@ class ASEAtomstoStructure(ConversionFeaturizer):
         self.aaa = AseAtomsAdaptor()
 
     def featurize(self, ase_atoms):
-        return self.aaa.get_structure(ase_atoms)
+        return (self.aaa.get_structure(ase_atoms),)
 
     def implementors(self):
         return ["Alex Dunn"]
