@@ -2,22 +2,33 @@ from matminer.featurizers.structure.bonding import (
     BagofBonds,
     BondFractions,
     GlobalInstabilityIndex,
-    StructuralHeterogeneity,
     MinimumRelativeDistances,
+    StructuralHeterogeneity,
 )
 from matminer.featurizers.structure.composite import JarvisCFID
-from matminer.featurizers.structure.matrix import CoulombMatrix, SineCoulombMatrix, OrbitalFieldMatrix
-from matminer.featurizers.structure.misc import EwaldEnergy, StructureComposition, XRDPowderPattern
+from matminer.featurizers.structure.matrix import (
+    CoulombMatrix,
+    OrbitalFieldMatrix,
+    SineCoulombMatrix,
+)
+from matminer.featurizers.structure.misc import (
+    EwaldEnergy,
+    StructureComposition,
+    XRDPowderPattern,
+)
 from matminer.featurizers.structure.order import (
-    DensityFeatures,
     ChemicalOrdering,
-    StructuralComplexity,
+    DensityFeatures,
     MaximumPackingEfficiency,
+    StructuralComplexity,
 )
 from matminer.featurizers.structure.rdf import (
-    RadialDistributionFunction,
     ElectronicRadialDistributionFunction,
     PartialRadialDistributionFunction,
+    RadialDistributionFunction,
 )
 from matminer.featurizers.structure.sites import SiteStatsFingerprint
-from matminer.featurizers.structure.symmetry import GlobalSymmetryFeatures, Dimensionality
+from matminer.featurizers.structure.symmetry import (
+    Dimensionality,
+    GlobalSymmetryFeatures,
+)
