@@ -1,22 +1,21 @@
-import os
 import copy
 import unittest
 import warnings
 from itertools import product
 
-import pandas as pd
 import numpy as np
-from sklearn.dummy import DummyRegressor, DummyClassifier
+import pandas as pd
 from pymatgen.core.structure import Structure
 from pymatgen.util.testing import PymatgenTest
+from sklearn.dummy import DummyClassifier, DummyRegressor
 
-from matminer.utils.caching import _get_all_nearest_neighbors
 from matminer.featurizers.base import (
     BaseFeaturizer,
     MultipleFeaturizer,
     StackedFeaturizer,
 )
 from matminer.featurizers.structure import SiteStatsFingerprint
+from matminer.utils.caching import _get_all_nearest_neighbors
 
 
 class SingleFeaturizer(BaseFeaturizer):
@@ -193,7 +192,7 @@ class TestBaseClass(PymatgenTest):
             self.assertIn("Them", implementors)
             self.assertEqual(2, len(implementors))
 
-            # Ensure BaseFeaturizer operation without overriden featurize_dataframe
+            # Ensure BaseFeaturizer operation without overridden featurize_dataframe
             with warnings.catch_warnings(record=True) as w:
                 data = multi_f.featurize_dataframe(data, "x")
                 self.assertEqual(len(w), 0)
@@ -306,7 +305,7 @@ class TestBaseClass(PymatgenTest):
         self.assertEqual(["ML prediction"], f.feature_labels())
 
         # Test classifier
-        model = DummyClassifier("prior")
+        model = DummyClassifier(strategy="prior")
         data["y"] = [0, 0, 1]
         model.fit(self.multi.featurize_many(data["x"]), data["y"])
 
@@ -447,7 +446,7 @@ class TestBaseClass(PymatgenTest):
         # Make sure multiplefeaturizer returns the correct sub-featurizer multiindex keys
 
         # Iterate through many tests: single/parallel, returning errors or not,
-        # multiindex or not, and interation over entires/featurizers
+        # multiindex or not, and interaction over entries/featurizers
 
         for mi, re, n, iter_entries in product([True, False], [True, False], [1, 2], [True, False]):
 
